# Import functions from chooser.py

from .chooser import chooser
from .chooser import sortchooser
from .chooser import revchooser

# Import functions from tests.py

from .tests import testnumbers
from .tests import testalphabet_lower
from .tests import testalphabet_upper
from .tests import testascii

__version__ = '1.1.1'